==> 0.2.6.tar.gz: android/src/main/kotlin/com/bundle/bundle_rave_pay/RavePayInitializer.java <==
package com.bundle.bundle_rave_pay;

import android.os.Parcel;
import android.os.Parcelable;

import java.util.ArrayList;

//import org.parceler.Parcel;

/**
 * Created by hamzafetuga on 21/07/2017.
 */

public class RavePayInitializer implements Parcelable {
    private final ArrayList<Integer> orderedPaymentTypesList = new ArrayList<>();
    String email;
    double amount;
    String publicKey;
    String encryptionKey;
    String txRef;
    String narration;
    String currency;
    String country;
    String fName;
    String lName;
    String meta;
    String subAccounts;
    String payment_plan;
    int theme;
    boolean staging = true;
    boolean isPreAuth = false;
    boolean displayFee = true;
    boolean showStagingLabel;
    private boolean isPermanent;
    private int frequency;
    private int duration;

    public RavePayInitializer(String email, double amount, String publicKey,
                              String encryptionKey, String txRef, String narration,
                              String currency, String country, String fName,
                              String lName, int theme,
                              boolean isPermanent, int duration, int frequency,
                              boolean staging, String meta, String subAccounts, String payment_plan, boolean isPreAuth,
                              boolean showStagingLabel, boolean displayFee, ArrayList<Integer> orderedPaymentTypesList) {
        this.email = email;
        this.amount = amount;
        this.publicKey = publicKey;
        this.encryptionKey = encryptionKey;
        this.txRef = txRef;
        this.narration = narration;
        this.currency = currency;
        this.country = country;
        this.fName = fName;
        this.lName = lName;
        this.isPermanent = isPermanent;
        this.duration = duration;
        this.frequency = frequency;
        this.theme = theme;
        this.staging = staging;
        this.meta = meta;
        this.subAccounts = subAccounts;
        this.payment_plan = payment_plan;
        this.isPreAuth = isPreAuth;
        this.showStagingLabel = showStagingLabel;
        this.displayFee = displayFee;
        if (!orderedPaymentTypesList.isEmpty())
            this.orderedPaymentTypesList.addAll(orderedPaymentTypesList);
        else this.orderedPaymentTypesList.add(RaveConstants.PAYMENT_TYPE_CARD);
    }

    public RavePayInitializer() {
    }

    protected RavePayInitializer(Parcel in) {
        email = in.readString();
        amount = in.readDouble();
        publicKey = in.readString();
        encryptionKey = in.readString();
        txRef = in.readString();
        narration = in.readString();
        currency = in.readString();
        country = in.readString();
        fName = in.readString();
        lName = in.readString();
        meta = in.readString();
        subAccounts = in.readString();
        payment_plan = in.readString();
        theme = in.readInt();
        staging = in.readByte() != 0;
        isPreAuth = in.readByte() != 0;
        displayFee = in.readByte() != 0;
        showStagingLabel = in.readByte() != 0;
        isPermanent = in.readByte() != 0;
        frequency = in.readInt();
        duration = in.readInt();
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(email);
        dest.writeDouble(amount);
        dest.writeString(publicKey);
        dest.writeString(encryptionKey);
        dest.writeString(txRef);
        dest.writeString(narration);
        dest.writeString(currency);
        dest.writeString(country);
        dest.writeString(fName);
        dest.writeString(lName);
        dest.writeString(meta);
        dest.writeString(subAccounts);
        dest.writeString(payment_plan);
        dest.writeInt(theme);
        dest.writeByte((byte) (staging ? 1 : 0));
        dest.writeByte((byte) (isPreAuth ? 1 : 0));
        dest.writeByte((byte) (displayFee ? 1 : 0));
        dest.writeByte((byte) (showStagingLabel ? 1 : 0));
        dest.writeByte((byte) (isPermanent ? 1 : 0));
        dest.writeInt(frequency);
        dest.writeInt(duration);
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<RavePayInitializer> CREATOR = new Creator<RavePayInitializer>() {
        @Override
        public RavePayInitializer createFromParcel(Parcel in) {
            return new RavePayInitializer(in);
        }

        @Override
        public RavePayInitializer[] newArray(int size) {
            return new RavePayInitializer[size];
        }
    };

    public boolean getShowStagingLabel() {
        return showStagingLabel;
    }

    public void showStagingLabel(boolean showStagingLabel) {
        this.showStagingLabel = showStagingLabel;
    }

    public String getMeta() {
        return meta;
    }

    public void setMeta(String meta) {
        this.meta = meta;
    }

    public String getSubAccount(){return subAccounts;}

    public void setSubAccount(String subAccounts){this.subAccounts=subAccounts;}

    public boolean isStaging() {
        return staging;
    }

    public ArrayList<Integer> getOrderedPaymentTypesList() {
        return orderedPaymentTypesList;
    }

    public void setStaging(boolean staging) {
        this.staging = staging;
    }

    public int getTheme() {
        return theme;
    }

    public void setTheme(int theme) {
        this.theme = theme;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public double getAmount() {
        return amount;
    }

    public void setAmount(double amount) {
        this.amount = amount;
    }

    public String getPublicKey() {
        return publicKey;
    }

    public void setPublicKey(String publicKey) {
        this.publicKey = publicKey;
    }

    public String getEncryptionKey() {
        return encryptionKey;
    }

    public void setEncryptionKey(String encryptionKey) {
        this.encryptionKey = encryptionKey;
    }

    public String getTxRef() {
        return txRef;
    }

    public void setTxRef(String txRef) {
        this.txRef = txRef;
    }

    public String getNarration() {
        return narration;
    }

    public void setNarration(String narration) {
        this.narration = narration;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getfName() {
        return fName;
    }

    public void setfName(String fName) {
        this.fName = fName;
    }

    public String getlName() {
        return lName;
    }

    public void setlName(String lName) {
        this.lName = lName;
    }

    public String getPayment_plan() {
        return payment_plan;
    }

    public void setPayment_plan(String payment_plan) {
        this.payment_plan = payment_plan;
    }

    public void setPreAuth(boolean isPreAuth) {
        this.isPreAuth = isPreAuth;
    }

    public boolean getIsPreAuth() { return  isPreAuth; }

    public boolean getIsDisplayFee() {
        return displayFee;
    }

    public void setIsDisplayFee(boolean displayFee) {
        this.displayFee = displayFee;
    }

    public boolean getIsPermanent() {
        return isPermanent;
    }

    public void setPermanent(boolean permanent) {
        this.isPermanent = permanent;
    }

    public int getFrequency() {
        return frequency;
    }

    public void setFrequency(int frequency) {
        this.frequency = frequency;
    }

    public int getDuration() {
        return duration;
    }

    public void setDuration(int duration) {
        this.duration = duration;
    }
}

==> 0.5.7.tar.gz: android/src/main/kotlin/com/bundle/bundle_rave_pay/RavePayInitializer.java <==
package com.bundle.bundle_rave_pay;

import android.os.Parcel;
import android.os.Parcelable;

import java.util.ArrayList;

//import org.parceler.Parcel;

/**
 * Created by hamzafetuga on 21/07/2017.
 */

public class RavePayInitializer implements Parcelable {
    private final ArrayList<Integer> orderedPaymentTypesList = new ArrayList<>();
    String email;
    double amount;
    String publicKey;
    String encryptionKey;
    String secretKey;
    String txRef;
    String narration;
    String currency;
    String country;
    String fName;
    String lName;
    String meta;
    String subAccounts;
    String payment_plan;
    int theme;
    boolean staging = true;
    boolean isPreAuth = false;
    boolean displayFee = true;
    boolean showStagingLabel;
    private boolean isPermanent;
    private int frequency;
    private int duration;

    public RavePayInitializer(String email, double amount, String publicKey,
                              String encryptionKey, String secretKey, String txRef, String narration,
                              String currency, String country, String fName,
                              String lName, int theme,
                              boolean isPermanent, int duration, int frequency,
                              boolean staging, String meta, String subAccounts, String payment_plan, boolean isPreAuth,
                              boolean showStagingLabel, boolean displayFee, ArrayList<Integer> orderedPaymentTypesList) {
        this.email = email;
        this.amount = amount;
        this.publicKey = publicKey;
        this.secretKey = secretKey;
        this.encryptionKey = encryptionKey;
        this.txRef = txRef;
        this.narration = narration;
        this.currency = currency;
        this.country = country;
        this.fName = fName;
        this.lName = lName;
        this.isPermanent = isPermanent;
        this.duration = duration;
        this.frequency = frequency;
        this.theme = theme;
        this.staging = staging;
        this.meta = meta;
        this.subAccounts = subAccounts;
        this.payment_plan = payment_plan;
        this.isPreAuth = isPreAuth;
        this.showStagingLabel = showStagingLabel;
        this.displayFee = displayFee;
        if (!orderedPaymentTypesList.isEmpty())
            this.orderedPaymentTypesList.addAll(orderedPaymentTypesList);
        else this.orderedPaymentTypesList.add(RaveConstants.PAYMENT_TYPE_CARD);
    }

    public RavePayInitializer() {
    }

    protected RavePayInitializer(Parcel in) {
        email = in.readString();
        amount = in.readDouble();
        publicKey = in.readString();
        encryptionKey = in.readString();
        secretKey = in.readString();
        txRef = in.readString();
        narration = in.readString();
        currency = in.readString();
        country = in.readString();
        fName = in.readString();
        lName = in.readString();
        meta = in.readString();
        subAccounts = in.readString();
        payment_plan = in.readString();
        theme = in.readInt();
        staging = in.readByte() != 0;
        isPreAuth = in.readByte() != 0;
        displayFee = in.readByte() != 0;
        showStagingLabel = in.readByte() != 0;
        isPermanent = in.readByte() != 0;
        frequency = in.readInt();
        duration = in.readInt();
    }

    @Override
    public void writeToParcel(Parcel dest, int flags) {
        dest.writeString(email);
        dest.writeDouble(amount);
        dest.writeString(publicKey);
        dest.writeString(encryptionKey);
        dest.writeString(secretKey);
        dest.writeString(txRef);
        dest.writeString(narration);
        dest.writeString(currency);
        dest.writeString(country);
        dest.writeString(fName);
        dest.writeString(lName);
        dest.writeString(meta);
        dest.writeString(subAccounts);
        dest.writeString(payment_plan);
        dest.writeInt(theme);
        dest.writeByte((byte) (staging ? 1 : 0));
        dest.writeByte((byte) (isPreAuth ? 1 : 0));
        dest.writeByte((byte) (displayFee ? 1 : 0));
        dest.writeByte((byte) (showStagingLabel ? 1 : 0));
        dest.writeByte((byte) (isPermanent ? 1 : 0));
        dest.writeInt(frequency);
        dest.writeInt(duration);
    }

    @Override
    public int describeContents() {
        return 0;
    }

    public static final Creator<RavePayInitializer> CREATOR = new Creator<RavePayInitializer>() {
        @Override
        public RavePayInitializer createFromParcel(Parcel in) {
            return new RavePayInitializer(in);
        }

        @Override
        public RavePayInitializer[] newArray(int size) {
            return new RavePayInitializer[size];
        }
    };

    public boolean getShowStagingLabel() {
        return showStagingLabel;
    }

    public void showStagingLabel(boolean showStagingLabel) {
        this.showStagingLabel = showStagingLabel;
    }

    public String getMeta() {
        return meta;
    }

    public void setMeta(String meta) {
        this.meta = meta;
    }

    public String getSubAccount(){return subAccounts;}

    public void setSubAccount(String subAccounts){this.subAccounts=subAccounts;}

    public boolean isStaging() {
        return staging;
    }

    public ArrayList<Integer> getOrderedPaymentTypesList() {
        return orderedPaymentTypesList;
    }

    public void setStaging(boolean staging) {
        this.staging = staging;
    }

    public int getTheme() {
        return theme;
    }

    public void setTheme(int theme) {
        this.theme = theme;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public double getAmount() {
        return amount;
    }

    public void setAmount(double amount) {
        this.amount = amount;
    }

    public String getPublicKey() {
        return publicKey;
    }

    public void setPublicKey(String publicKey) {
        this.publicKey = publicKey;
    }

    public String getEncryptionKey() {
        return encryptionKey;
    }

    public void setEncryptionKey(String encryptionKey) {
        this.encryptionKey = encryptionKey;
    }

    public String getTxRef() {
        return txRef;
    }

    public void setTxRef(String txRef) {
        this.txRef = txRef;
    }

    public String getNarration() {
        return narration;
    }

    public void setNarration(String narration) {
        this.narration = narration;
    }

    public String getCurrency() {
        return currency;
    }

    public void setCurrency(String currency) {
        this.currency = currency;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getfName() {
        return fName;
    }

    public void setfName(String fName) {
        this.fName = fName;
    }

    public String getlName() {
        return lName;
    }

    public void setlName(String lName) {
        this.lName = lName;
    }

    public String getPayment_plan() {
        return payment_plan;
    }

    public void setPayment_plan(String payment_plan) {
        this.payment_plan = payment_plan;
    }

    public void setPreAuth(boolean isPreAuth) {
        this.isPreAuth = isPreAuth;
    }

    public boolean getIsPreAuth() { return  isPreAuth; }

    public boolean getIsDisplayFee() {
        return displayFee;
    }

    public void setIsDisplayFee(boolean displayFee) {
        this.displayFee = displayFee;
    }

    public boolean getIsPermanent() {
        return isPermanent;
    }

    public void setPermanent(boolean permanent) {
        this.isPermanent = permanent;
    }

    public int getFrequency() {
        return frequency;
    }

    public void setFrequency(int frequency) {
        this.frequency = frequency;
    }

    public int getDuration() {
        return duration;
    }

    public void setDuration(int duration) {
        this.duration = duration;
    }

    public String getSecretKey() {
        return secretKey;
    }

    public void setSecretKey(String secretKey) {
        this.secretKey = secretKey;
    }
}
